"""Cymbaline UI colors.

htmlbgcolor         - background color for html playlist
status              - Playing:
score_0_25          - track scores from 0 to 25
prompt_brackets     - brackets for the prompt [>]
playing             - the > in [>] prompt
track_name          - track name in track list
dir_name            - dir name in dir list
header              - Playlist: etc
cur_track           - current track
cur_dir             - current dir
current_bracket     - bracket for score of current track
info                - id3 info

Colors: white, black, gray, blue, green, cyan, brown, red, pink
lgray, lblue, lgreen, lcyan, purple, yellow, lred

Optionally you can add the background color:

info = "white", "black" # white foreground, black background
"""

import conf
import curses

class Col:
    _shared = {}

    def __init__(self):
        self.__dict__ = self._shared

    def init_colors(self):

        self.htmlbgcolor       = 'white'
        self.progress          = 'white'
        self.default           = 'white'
        self.options           = 'white'
        self.status            = 'white'
        self.score_0_25        = 'white'
        self.score_25_50       = 'white'
        self.score_50_75       = 'white'
        self.dir_name          = 'white'
        self.score_75_100      = 'white'
        self.prompt_brackets   = 'white'
        self.playing           = 'white'
        self.stopped           = 'white'
        self.paused            = 'white'
        self.track_name        = 'white'
        self.albumname         = 'white'
        self.header            = 'white'
        self.cur_track         = 'white'
        self.cur_dir           = 'white'
        self.startup           = 'white'
        self.time              = 'white'
        self.progress_bar      = 'white'
        self.progr_done        = 'white'
        self.progr_perc        = 'white'
        self.current_bracket   = 'white'
        self.info              = 'white'
        self.help_title        = 'white'
        self.help_body         = 'white'
        self.bar               = 'white'
        self.error             = 'white'
        self.normal            = 'white'


        if curses.has_colors():
            curses.init_pair(1, curses.COLOR_RED, curses.COLOR_BLACK)
            curses.init_pair(2, curses.COLOR_GREEN, curses.COLOR_BLACK)
            curses.init_pair(3, curses.COLOR_YELLOW, curses.COLOR_BLACK)
            curses.init_pair(4, curses.COLOR_BLUE, curses.COLOR_BLACK)
            curses.init_pair(5, curses.COLOR_MAGENTA, curses.COLOR_BLACK)
            curses.init_pair(6, curses.COLOR_CYAN, curses.COLOR_BLACK)
            curses.init_pair(7, curses.COLOR_WHITE, curses.COLOR_BLACK)
            curses.init_pair(8, curses.COLOR_WHITE, curses.COLOR_WHITE)

        if curses.has_colors():
            if conf.bg == "dark":
                self.htmlbgcolor       = 'white'
                self.progress          = curses.color_pair(8)
                self.default           = curses.color_pair(7)
                self.options           = curses.color_pair(6)
                self.status            = curses.color_pair(3)
                self.score_0_25        = curses.color_pair(1)
                self.score_25_50       = curses.color_pair(3)
                self.score_50_75       = curses.color_pair(2)
                self.dir_name          = curses.color_pair(6)
                self.score_75_100      = curses.color_pair(6)
                self.prompt_brackets   = curses.color_pair(7)
                self.playing           = curses.color_pair(2)
                self.stopped           = curses.color_pair(1)
                self.paused            = curses.color_pair(6)
                self.track_name        = curses.color_pair(2)
                self.albumname         = curses.color_pair(6)
                self.header            = curses.color_pair(3)
                self.cur_track         = curses.color_pair(1)
                self.cur_dir           = curses.color_pair(3)
                self.startup           = curses.color_pair(6)
                self.time              = curses.color_pair(2)
                self.progress_bar      = curses.color_pair(3)
                self.progr_done        = curses.color_pair(3)
                self.progr_perc        = curses.color_pair(0)
                self.current_bracket   = curses.color_pair(3)
                self.info              = curses.color_pair(3)
                self.help_title        = curses.color_pair(3)
                self.help_body         = curses.color_pair(2)
                self.bar               = curses.color_pair(3)
                self.error             = curses.color_pair(1)
                self.normal            = curses.color_pair(2)

            else:
                htmlbgcolor       = 'white'
                self.default           = curses.color_pair(0)
                self.dir_name          = curses.color_pair(2)
                self.status            = curses.color_pair(4)
                self.score_0_25        = curses.color_pair(1)
                self.score_25_50       = curses.color_pair(0)
                self.score_50_75       = curses.color_pair(4)
                self.score_75_100      = curses.color_pair(4)
                self.prompt_brackets   = curses.color_pair(7)
                self.playing           = curses.color_pair(4)
                self.stopped           = curses.color_pair(1)
                self.paused            = curses.color_pair(4)
                self.track_name        = curses.color_pair(0)
                self.albumname         = curses.color_pair(4)
                self.header            = curses.color_pair(4)
                self.cur_track         = curses.color_pair(1)
                self.cur_dir           = curses.color_pair(1)
                self.startup           = curses.color_pair(4)
                self.time              = curses.color_pair(0)
                self.progress_bar      = curses.color_pair(4)
                self.progr_done        = curses.color_pair(4)
                self.progr_perc        = curses.color_pair(7)
                self.current_bracket   = curses.color_pair(4)
                self.info              = curses.color_pair(4)
                self.help_title        = curses.color_pair(1)
                self.help_body         = curses.color_pair(4)
                self.bar               = curses.color_pair(1)
                self.error             = curses.color_pair(1)
                self.normal            = curses.color_pair(2)
                self.options           = curses.color_pair(6)

colors = Col()
