import os
import curses
import ui
import signal
import sys
import copy
import time
import threading
import avkutil
import conf
from player import player, Poll
from scores import scores
from stats import stats
from data import data
import modes
import rand
import misc
import help
import key
import args
from log import log
from update import Check
from id3cy import id3
from cycurses import cycurses
from colors import colors
from debug import debug
from traceback import *
from status import stat

do_quit = 0
vol = avkutil.vol()


class Redraw(threading.Thread):
    def run(self):
        while 1:
            if do_quit:
                return
            time.sleep(.2)
            if ui.doredraw and not do_quit:
                ui.redraw()


def loadpl():
    """Load playlist.

    User must either specify multiple directories to build playlist from
    or one (only one) playlist name. If nothing is specified, last
    playlist is used.
    """

    _args = args.parse()
    err = 0
    global pl   # this is for keys.py
    from playlist import pl
    if not _args:
        if data.lastplaylist:
            pl.__dict__ = data.playlists[data.lastplaylist].__dict__
        else:
            err = 1
    elif os.path.exists(_args[0]):
        okay = pl.init(_args)
        if not okay:
            quit()
        name = "no name"
        data.lastplaylist = name
        data.playlists[name] = pl
        if data.threshold:
            # we need to save full playlist data then we'll apply
            # threshold
            pl.full_list = copy.deepcopy(pl.albums)
            pl.set_threshold(data.threshold)
    elif data.playlists.has_key(_args[0]):
        debug("loading playlist by name..")
        pl.__dict__ = data.playlists[_args[0]].__dict__
        pl.update()
        data.lastplaylist = _args[0]
    else:
        err = 1
    if err:
        print """
        Error loading playlist.
        Cy needs a directory or a playlist name - not mp3 files!
        """
        cycurses.win.addnstr(0, 0, "Invalid argument, need a directory name or playlist name (case sensitive)", ui.w()-1)
        cycurses.win.addnstr(1, 0, 'Hit any key..', ui.w()-1)
        cycurses.win.getch()
        quit()


def loop():
    last_cmd = None
    last_num = None
    last_ctype = None
    #ui.clear_progress()
    while 1:
        answer = ui.uinput()
#        if ui.do_clear:
#            ui.clear()
#            ui.do_clear = 0
        if answer:
            ctype, num, cmd = answer
        else:
            ui.tracks_window = 1
            ui.doredraw = 1
            ui.fullredraw()
            continue
        if cmd == 'e' and last_cmd:
            # repeat last command
            if last_cmd.startswith("<n>"):
# otherwise <n> will double up later
                last_cmd = last_cmd[3:]
            cmd = last_cmd
            ctype = last_ctype
            num = last_num
        if ctype == 'n':
            # normal command
            eval('%s()' % key.bindings[cmd])
        elif ctype == 'N':
            # number command
            cmd = "<n>" + cmd
            eval('%s(%s)' % (key.bindings[cmd], num))
        if key.bindings[cmd] not in key.no_redraw:
            # for some commands we need to redraw full screen
            ui.tracks_window = 1
            ui.fullredraw()
        last_cmd, last_num, last_ctype = cmd, num, ctype


def quit():
    """Quit: save data, show statistics.

    Save persistant options to the data file; save scores.
    """

    ui.doredraw = 0
    chk.quit = 1
    global do_quit
    do_quit = 1
    player.do_quit = 1
    player.stop()
    # ui.display(stats.tracks_played)
    # ui.display(stats.time_spent())
    data.save()
    scores.save()
    if chk.new_version:
        mid = ui.h()/2
        msg = 'New version of Cymbaline is available: %s' % chk.new_version
        ui.doredraw = 0
        ui.clear()
        cycurses.win.addnstr(mid-1, 0, msg.center(ui.w()), ui.w()-1)
        cycurses.win.addnstr(mid, 0, 'Get it at http://www.silmarill.org/cymbaline.htm'.center(
                ui.w()), ui.w()-1)
        cycurses.win.addnstr(mid+1, 0, 
                'Hit any key..'.center(ui.w()), ui.w()-1)
        cycurses.win.getch()
#    debug("in quit() before exit.")
    sys.exit()


def test_queue():
    """ Test random queue tracks (were they removed?). 
    
    no longer needed because we now always reload queue
    """
    for n in data.queue:
        track = n[0]
        if not os.path.exists(track.path):
            # refresh queue
            data.queue = []
            rand.queue()
            break


def main(win):
    """Start main program loop().  """

    global chk

    ui.mk_rlock()
#    curses.delay_output(3000)
    if curses.has_colors():
        # only works if there's color support in the terminal?
        curses.curs_set(0)
    colors.init_colors()
    cycurses.set_win(win)
    chk = Check()
    chk.start()
    Poll().start()
    loadpl()
    Redraw().start()
    from playlist import pl
    if data.random != 'queue' and data.last_track:
        debug('last track: ' + data.last_track + '\n')
        pl.find(1, data.last_track, show_error=0, OnlyFind=1)
        debug('index: %s\n' % pl.index)
#        debug('Exception: ' + sys.exc_info()[1] + '\n')
#        debug('found index: ' + pl.index + '\n')
    elif data.random == 'queue':
        rand.reload_queue()
    # we should really not need this at all..
    #if not data.last_track:
        # first run
    #    pl.first_album()
    if conf.play_on_start:
        if data.random == 'queue':
            t, di, i = data.queue[0]
            pl.update(di, i)
        player.play()
    ui.fullredraw()
    loop()
#    except:
#        debug("exception in main: %s\n" % sys.exc_info()[0])
#        debug("exception in main: %s\n" % sys.exc_info()[1])
#        debug("exception in main: %s\n" % sys.exc_info()[2])
#        err = open("cy.err",'a')
#        print_tb(sys.exc_info()[2], None, err)
#        print_exc(None, err)
